package com.supermap.samplecode.data;

import java.awt.BorderLayout;
import java.awt.Font;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.util.ArrayList;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;
import javax.swing.filechooser.FileFilter;

import com.supermap.data.EngineType;
import com.supermap.data.Workspace;

/**
 * <p>
 * Title:数据源管理
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明----------------------------
 * 此文件为SuperMap Objects Java 的示范代码 
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：示范如何打开和新建数据源
 * 2、示例数据：无
 * 3、关键类型/成员: 
 *      Datasources.open 方法
 *      Datasources.create 方法
 * 4、使用步骤：
 *  (1)点击“打开”面板，执行打开数据源的功能
 *  (2)点击“新建”面板，执行新建数据源的功能
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * </p>
 * 
 */
 
 /**
 * <p>
 * Title Manage Datasource
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------Copyright Statement----------------------------
 * SuperMap Objects Java Sample Code 
 * Copyright: SuperMap Software Co., Ltd. All Rights Reserved.
 * ------------------------------------------------------------------------------
 *-----------------------Description--------------------------
 * 
 * 1.Sample Code Description: This sample demonstrates how to open and new a datasource
 * 2. Data: None
 * 3. Key classes and members 
 *      Datasources.open method
 *      Datasources.create method
 * 4. Steps:
 *   (1) Click the "Open" panel to implement the open datasource operation.
 *   (2) Click the "New" panel to implement the new datasource operation.
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * CopyRight: SuperMap Software Co., Ltd.
 * </p>
 * 
 */
 
public class MainFrame extends JFrame {

	private static final long serialVersionUID = 1L;

	private JPanel m_contentPane;

	private Workspace m_workspace;

	private JTextArea m_textFieldDatasourceInfo;

	private JTabbedPane m_tabbedPaneManage;

	private JScrollPane m_scrollPaneDatasourceInfo;

	private SampleRun m_sampleRun;

	/**
	 * 获取m_scrollPaneDatasourceInfo	 
	 * Get m_scrollPaneDatasourceInfo 
	 */
	private JScrollPane getScrollPaneWorkspaceInfo() {
		if (m_scrollPaneDatasourceInfo == null) {

			m_scrollPaneDatasourceInfo = new JScrollPane(
					getTextAreaDatasourceInfo());
			m_scrollPaneDatasourceInfo.setBorder(BorderFactory
					.createTitledBorder(getText("m_scrollPaneDatasourceInfo")));

		}
		return m_scrollPaneDatasourceInfo;
	}

	/**
	 * 获取m_textFieldDatasourceInfo	 
	 * Get the m_textFieldDatasourceInfo
	 */
	private JTextArea getTextAreaDatasourceInfo() {
		if (m_textFieldDatasourceInfo == null) {
			Font font = new Font("Serif", Font.PLAIN, 18);
			m_textFieldDatasourceInfo = new JTextArea(8, 40);
			m_textFieldDatasourceInfo.setFont(font);
			m_textFieldDatasourceInfo.setEditable(false);
		}
		return m_textFieldDatasourceInfo;
	}

	/**
	 * 获取m_tabbedPaneManage	 
	 * Get m_tabbedPaneManage  
	 */
	private JTabbedPane getTabbedPaneManage() {
		if (m_tabbedPaneManage == null) {
			m_tabbedPaneManage = new JTabbedPane();
			m_tabbedPaneManage.addTab(getText("m_tabbedPaneManage1"), null, new DatasourcePanel(
					m_sampleRun, getText("m_tabbedPaneManage1")), null);
			m_tabbedPaneManage.addTab(getText("m_tabbedPaneManage2"), null, new DatasourcePanel(
					m_sampleRun, getText("m_tabbedPaneManage2")), null);
		}
		return m_tabbedPaneManage;
	}

	/**
	 * 程序入口点
	 * Entrance to the program
	 */
	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				MainFrame thisClass = new MainFrame();
				thisClass.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
				thisClass.setVisible(true);
			}
		});
	}

	/**
	 * 构造函数
	 * Constructor
	 */
	public MainFrame() {
		super();
		initialize();
	}

	/**
	 * 初始化窗体
	 * Initialize the form.
	 */
	private void initialize() {
		// 最大化显示窗体
		// Maximize the form
		this.setExtendedState(Frame.MAXIMIZED_BOTH);
		this.setSize(800, 500);
		m_workspace = new Workspace();
		m_sampleRun = new SampleRun(m_workspace, getTextAreaDatasourceInfo(),getScrollPaneWorkspaceInfo());
		this.setContentPane(getJContentPane());
		this.setTitle(getText("m_title"));
		this.addWindowListener(new java.awt.event.WindowAdapter() {

			// 在窗体关闭时，需要释放相关的资源
			// Release resources when you close the window
			public void windowClosing(java.awt.event.WindowEvent e) {
				m_workspace.dispose();
			}
		});
	}

	/**
	 * 获取m_contentPane
	 * Get m_contentPane
	 */
	private JPanel getJContentPane() {
		if (m_contentPane == null) {
			m_contentPane = new JPanel();
			m_contentPane.setLayout(new BorderLayout());
			m_contentPane.add(getScrollPaneWorkspaceInfo(), BorderLayout.CENTER);
			m_contentPane.add(getTabbedPaneManage(), BorderLayout.WEST);
		}
		return m_contentPane;
	}

	// 根据语言设置text是中文还是英文
	// To change text to English or Chinede by CurrentCulture
	private String getText(String id)
	{
		String text = "";
		if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if(id == "m_scrollPaneDatasourceInfo")
			{
				text = "数据源信息";
			} 
			if(id == "m_tabbedPaneManage1")
			{
				text = "打开";
			} 
			if(id == "m_tabbedPaneManage2")
			{
				text = "新建";
			} 
			if(id == "m_title")
			{
				text = "数据源管理";
			} 
		}
		else
		{
			if(id == "m_scrollPaneDatasourceInfo")
			{
				text = "Datasource Information";
			} 
			if(id == "m_tabbedPaneManage1")
			{
				text = "Open";
			} 
			if(id == "m_tabbedPaneManage2")
			{
				text = "Create";
			} 
			if(id == "m_title")
			{
				text = "Manage Datasource";
			} 
		}
		return text ;
	}

}

/**
 * 这个类表示JComboBox里面的数据
 * This class indicates the data in the JComboBox.
 */
class ComboxData {

	String m_name;

	EngineType m_engineType;

	public ComboxData(String name, EngineType engineType) {
		this.m_name = name;
		this.m_engineType = engineType;
	}

	public EngineType getEngineType() {
		return m_engineType;
	}

	public void setEngineType(EngineType engineType) {
		this.m_engineType = engineType;
	}

	public String getName() {
		return m_name;
	}

	public void setName(String name) {
		this.m_name = name;
	}

	/**
	 * 根据不同的引擎获取不同的字符串
	 * Get different strings according to different engines
	 */
	public String toString() {
		String temp = "";
		if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if (m_engineType.equals(EngineType.IMAGEPLUGINS)) {
				temp = "影像只读引擎类型";
			} else if (m_engineType.equals(EngineType.UDB)) {
				temp = "UDB 引擎类型";
			} else if (m_engineType.equals(EngineType.ORACLEPLUS)) {
				temp = "ORACLE 引擎类型";
			} else if (m_engineType.equals(EngineType.SQLPLUS)) {
				temp = "SQL Server 引擎类型";
			} else if (m_engineType.equals(EngineType.POSTGRESQL)){
				temp = "PostgreSQL 引擎类型";
			} else if (m_engineType.equals(EngineType.DB2)) {
				temp = "DB2 引擎类型";
			} 
			else if (m_engineType.equals(EngineType.OGC)) {
				temp = "OGC 引擎类型，针对于网络数据源";
			} else if (m_engineType.equals(EngineType.GOOGLEMAPS)) {
				temp = "GoogleMaps 引擎类型";
			} else if (m_engineType.equals(EngineType.SUPERMAPCLOUD)) {
				temp = "SuperMapCloud 引擎类型";
			} else if (m_engineType.equals(EngineType.ISERVERREST)) {
				temp = "ISERVERREST 引擎类型";
			}
		}
		else
		{
			if (m_engineType.equals(EngineType.IMAGEPLUGINS)) {
                  temp = "Engine For Image Reading Only";         
            } else if (m_engineType.equals(EngineType.UDB)) {
                  temp = "Engine for UDB";
            } else if (m_engineType.equals(EngineType.ORACLEPLUS)) {
                  temp = "Engine for ORACLE";
            } else if (m_engineType.equals(EngineType.SQLPLUS)) {
                  temp = "Engine for SQL Server";
            } else if (m_engineType.equals(EngineType.POSTGRESQL)){
                  temp = "Engine for PostgreSQL";
            } else if (m_engineType.equals(EngineType.DB2)) {
                  temp = "Engine for DB2";
            } 
            else if (m_engineType.equals(EngineType.OGC)) {
                  temp = "Engine for OGC for network datasource";
            } else if (m_engineType.equals(EngineType.GOOGLEMAPS)) {
                  temp = "Engine for GoogleMaps";
            } else if (m_engineType.equals(EngineType.SUPERMAPCLOUD)) {
                  temp = "Engine for SuperMapCloud";
            } else if (m_engineType.equals(EngineType.ISERVERREST)) {
                  temp = "Engine for ISERVERREST";
            } 
		}
		return temp;
	}

	/**
	 * 根据不同的引擎获取不同的文件后缀
	 * Get different extension name by the different engine.
	 */
	public String getFileExtensionName() {
		String temp = "";
		if (m_engineType.equals(EngineType.IMAGEPLUGINS)) {
			temp = ".tif;.sit;.bmp;.jpg;.png;.sci;.tga;.raw";
		} else if (m_engineType.equals(EngineType.UDB)) {
			temp = ".udb";
		} else if (m_engineType.equals(EngineType.OGC)) {
			temp = "";
		}
		return temp;
	}
}

/**
 * 这个类表示打开或者新建的Tab页面
 * This class indicates the Open or Initialize panel.
 */
class DatasourcePanel extends JPanel {

	private static final long serialVersionUID = 1L;

	private JLabel m_labelServer;

	private JLabel m_labelPath;

	private JTextField m_textFieldServer;

	private JTextField m_textFieldPath;

	private JButton m_buttonBrowse;

	private JLabel m_labelDatabase;

	private JTextField m_textFieldDatabase;

	private JLabel m_labelUserName;

	private JLabel m_labelURLPath;

	private JTextField m_textFieldUserName;

	private JTextField m_textFieldURLPath;
	
	private JLabel m_labelWebPath;
	
	private JTextField m_textFieldWebPath;
	
	private JLabel m_labelKey;
	
	private JTextField m_textFieldKey;

	private JLabel m_labelPassword;

	private JPasswordField m_textFieldPassword;

	private JButton m_buttonConfirm;

	private JLabel m_labelEngineType;

	private JComboBox m_comboBoxEngineType;

	private Box m_boxEngineType;

	private Box m_boxServer;

	private Box m_boxPath;

	private Box m_boxDatabase;

	private Box m_boxUserName;

	private Box m_boxURL;
	
	private Box m_boxWeb;
	
	private Box m_boxKey;

	private Box m_boxPassword;

	private Box m_boxConfirm;

	private Box m_boxDatasourceOpenInfo;

	private SampleRun m_sampleRun;

	private String m_name;

	public DatasourcePanel(SampleRun sampleRun, String name) {
		super();
		this.m_name = name;
		this.m_sampleRun = sampleRun;
		add(getVerticalBoxDatasourceInfoOpen());
	}

	private Box getVerticalBoxDatasourceInfoOpen() {
		if (m_boxDatasourceOpenInfo == null) {
			m_boxDatasourceOpenInfo = Box.createVerticalBox();
			// 先把所有控件都添加上
			// Add all the items.
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					Box.createVerticalStrut(20));
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxEngineType());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					Box.createVerticalStrut(10));
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxPath());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxServer());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					Box.createVerticalStrut(10));
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxDatabase());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					Box.createVerticalStrut(10));
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxPassword());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					Box.createVerticalStrut(10));
			m_boxDatasourceOpenInfo.add(getBoxUserName());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					Box.createVerticalStrut(10));
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxURL());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxConfirm());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					Box.createVerticalStrut(10));
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxWeb());
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					Box.createVerticalStrut(10));
			DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen().add(
					getBoxKey());

			if (getComboxEngineType().getItemCount() > 0) {
				getComboxEngineType().setSelectedIndex(0);
			}

		}

		return m_boxDatasourceOpenInfo;
	}

	private JComboBox getComboxEngineType() {
		if (m_comboBoxEngineType == null) {
			m_comboBoxEngineType = new JComboBox();
			m_comboBoxEngineType.setMaximumRowCount(10);
			// 根据系统支持的引擎类型 初始化combox
			// Initialize combox by the available engine type.
			EngineType[] engineTypes = {
					EngineType.IMAGEPLUGINS,
					EngineType.UDB,
					EngineType.ORACLEPLUS,
					EngineType.SQLPLUS,
					EngineType.POSTGRESQL,
					EngineType.DB2,
					EngineType.OGC,
					EngineType.GOOGLEMAPS,
					EngineType.SUPERMAPCLOUD,
					EngineType.ISERVERREST,
					};
			for (int i = 0; i < engineTypes.length; i++) {
				EngineType type = engineTypes[i];
				ComboxData data = new ComboxData(type.toString(), type);
				
				// 过滤掉不需要显示的引擎类型
				// Filter engine types that are not necessary to display
				if (m_name.equals(getText("m_name1"))) {
					if (type.equals(EngineType.OGC)
							|| type.equals(EngineType.IMAGEPLUGINS)
							|| type.equals(EngineType.GOOGLEMAPS)
							|| type.equals(EngineType.SUPERMAPCLOUD)
							|| type.equals(EngineType.ISERVERREST))
						continue;
				}
				m_comboBoxEngineType.addItem(data);
			}
			m_comboBoxEngineType.addActionListener(new ActionListener() {
				// 根据不同的引擎,构造不同的界面
				// Initialize diffferent interface by the different engines.
				public void actionPerformed(ActionEvent e) {
					// 清空textField里面的内容
					// Clear the content in the textField
					clearTextField();
					EngineType type = ((ComboxData) m_comboBoxEngineType
							.getSelectedItem()).getEngineType();
					if (type.equals(EngineType.IMAGEPLUGINS)
							|| type.equals(EngineType.UDB)) {
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.removeAll();
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(20));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxEngineType());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(10));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxPath());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(10));
						if (m_name.equals(getText("m_name1"))) {
							m_labelDatabase.setText(getText("m_name2"));
							DatasourcePanel.this
									.getVerticalBoxDatasourceInfoOpen().add(
											getBoxDatabase());
							DatasourcePanel.this
									.getVerticalBoxDatasourceInfoOpen().add(
											Box.createVerticalStrut(10));
						}
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxConfirm());
						DatasourcePanel.this.validate();
					} else if (type.equals(EngineType.OGC)
							|| type.equals(EngineType.ISERVERREST)) {
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.removeAll();
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(20));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxEngineType());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(10));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxURL());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(10));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxConfirm());
						DatasourcePanel.this.validate();
					} else if (type.equals(EngineType.GOOGLEMAPS)) {
						m_textFieldWebPath.setText("http://maps.google.com");
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.removeAll();
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(20));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxEngineType());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(10));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxWeb());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
						.add(Box.createVerticalStrut(10));
				        DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
						.add(getBoxKey());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(10));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxConfirm());
						DatasourcePanel.this.validate();
					} else if (type.equals(EngineType.SUPERMAPCLOUD)) {
						m_textFieldWebPath.setText("http://supermapcloud.com");
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.removeAll();
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(20));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxEngineType());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(10));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxWeb());
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(Box.createVerticalStrut(10));
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.add(getBoxConfirm());
						DatasourcePanel.this.validate();
					} else if (type.equals(EngineType.ORACLEPLUS)
							|| type.equals(EngineType.SQLPLUS)
							|| type.equals(EngineType.POSTGRESQL)) {
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
								.removeAll();
						m_boxDatasourceOpenInfo
								.add(Box.createVerticalStrut(20));
						m_boxDatasourceOpenInfo.add(getBoxEngineType());
						m_boxDatasourceOpenInfo
								.add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo.add(getBoxServer());
						m_boxDatasourceOpenInfo
								.add(Box.createVerticalStrut(10));
						m_labelDatabase.setText(getText("m_name3"));
						m_boxDatasourceOpenInfo.add(getBoxDatabase());
						m_boxDatasourceOpenInfo
								.add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo.add(getBoxUserName());
						m_boxDatasourceOpenInfo
								.add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo.add(getBoxPassword());
						m_boxDatasourceOpenInfo
								.add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo
								.add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo.add(getBoxConfirm());
						DatasourcePanel.this.validate();
					} else if (type.equals(EngineType.DB2)) {
						DatasourcePanel.this.getVerticalBoxDatasourceInfoOpen()
						        .removeAll();
						m_boxDatasourceOpenInfo
						        .add(Box.createVerticalStrut(20));
						m_boxDatasourceOpenInfo.add(getBoxEngineType());
						m_boxDatasourceOpenInfo
						        .add(Box.createVerticalStrut(10));
						m_labelDatabase.setText(getText("m_name3"));
						m_boxDatasourceOpenInfo.add(getBoxDatabase());
						m_boxDatasourceOpenInfo
						        .add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo.add(getBoxUserName());
						m_boxDatasourceOpenInfo
						        .add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo.add(getBoxPassword());
						m_boxDatasourceOpenInfo
						        .add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo
						        .add(Box.createVerticalStrut(10));
						m_boxDatasourceOpenInfo.add(getBoxConfirm());
						DatasourcePanel.this.validate();
						}
				}
			});
		}

		return m_comboBoxEngineType;
	}

	private Box getBoxEngineType() {
		if (m_boxEngineType == null) {
			m_boxEngineType = Box.createHorizontalBox();
			m_labelEngineType = new JLabel();
			m_labelEngineType.setText(getText("m_labelEngineType"));
			m_boxEngineType.add(m_labelEngineType);
			m_boxEngineType.add(Box.createHorizontalStrut(30));
			m_boxEngineType.add(getComboxEngineType());

		}

		return m_boxEngineType;
	}

	private Box getBoxPath() {
		if (m_boxPath == null) {
			m_boxPath = Box.createHorizontalBox();
			m_labelPath = new JLabel();
			m_labelPath.setText(getText("m_labelPath"));
			m_boxPath.add(m_labelPath);
			m_boxPath.add(Box.createHorizontalStrut(54));
			m_textFieldPath = new JTextField(14);
			m_textFieldPath.setText("");
			m_textFieldPath.setMaximumSize(m_textFieldPath.getPreferredSize());
			m_boxPath.add(m_textFieldPath);
			m_boxPath.add(Box.createHorizontalStrut(5));
			m_buttonBrowse = new JButton();
			m_buttonBrowse.setText(getText("m_buttonBrowse"));
			m_buttonBrowse.addActionListener(new ActionListener() {

				public void actionPerformed(ActionEvent e) {
					JFileChooser fileChooser = new JFileChooser();
					fileChooser
							.setCurrentDirectory(new File("../../SampleData"));
					String temp = ((ComboxData) m_comboBoxEngineType
							.getSelectedItem()).getFileExtensionName();

					if (m_name.equals(getText("m_name4"))) {
						FileNameExtensionFilter filter = new FileNameExtensionFilter(
								temp);
						String[] extensions = temp.split(";");
						for (int i = 0; i < extensions.length; i++) {
							filter.addExtension(extensions[i]);
						}
						fileChooser.addChoosableFileFilter(filter);
						if (fileChooser.showOpenDialog(null) == JFileChooser.APPROVE_OPTION) {
							File selectedFile = fileChooser.getSelectedFile();
							if (selectedFile == null) {
								return;
							}
							String filePath = selectedFile.getPath();
							m_textFieldPath.setText(filePath);
						}
					} else {
						fileChooser
								.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
						if (fileChooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION) {
							File selectedFile = fileChooser.getSelectedFile();
							if (selectedFile == null) {
								return;
							}
							String filePath = selectedFile.getPath();
							m_textFieldPath.setText(filePath);
						}
					}
				}

			});
			m_boxPath.add(m_buttonBrowse);

		}
		return m_boxPath;
	}

	private Box getBoxServer() {
		if (m_boxServer == null) {
			m_boxServer = Box.createHorizontalBox();
			m_labelServer = new JLabel();
			m_labelServer.setText(getText("m_labelServer"));
			m_boxServer.add(m_labelServer);
			if (m_name.equals(getText("m_name1"))) {
				m_boxServer.add(Box.createHorizontalStrut(30));
			} else {
				m_boxServer.add(Box.createHorizontalStrut(20));
			}

			m_boxServer.add(Box.createGlue());
			m_textFieldServer = new JTextField(20);
			m_textFieldServer.setText("");
			m_textFieldServer.setMaximumSize(m_textFieldServer
					.getPreferredSize());
			m_boxServer.add(m_textFieldServer);

		}
		return m_boxServer;
	}

	private Box getBoxDatabase() {
		if (m_boxDatabase == null) {
			m_boxDatabase = Box.createHorizontalBox();
			m_labelDatabase = new JLabel();
			m_labelDatabase.setText(getText("m_name3"));
			m_boxDatabase.add(m_labelDatabase);
			m_boxDatabase.add(Box.createHorizontalStrut(18));
			m_boxDatabase.add(Box.createGlue());
			m_textFieldDatabase = new JTextField(20);
			m_textFieldDatabase.setMaximumSize(m_textFieldDatabase
					.getPreferredSize());
			m_textFieldDatabase.setText("");
			m_boxDatabase.add(m_textFieldDatabase);
		}

		return m_boxDatabase;
	}

	private Box getBoxUserName() {
		if (m_boxUserName == null) {
			m_boxUserName = Box.createHorizontalBox();
			m_labelUserName = new JLabel();
			m_labelUserName.setText(getText("m_labelUserName"));
			m_boxUserName.add(m_labelUserName);
			m_boxUserName.add(Box.createHorizontalStrut(31));
			m_boxUserName.add(Box.createGlue());
			m_textFieldUserName = new JTextField(20);
			m_textFieldUserName.setMaximumSize(m_textFieldUserName
					.getPreferredSize());
			m_textFieldUserName.setText("");
			m_boxUserName.add(m_textFieldUserName);
		}
		return m_boxUserName;
	}

	private Box getBoxURL() {
		if (m_boxURL == null) {
			m_boxURL = Box.createHorizontalBox();
			m_labelURLPath = new JLabel();
			m_labelURLPath.setText(getText("m_labelURLPath"));
			m_boxURL.add(m_labelURLPath);
			m_boxURL.add(Box.createHorizontalStrut(56));
			m_boxURL.add(Box.createGlue());
			m_textFieldURLPath = new JTextField(20);
			m_textFieldURLPath.setMaximumSize(m_textFieldURLPath
					.getPreferredSize());
			m_textFieldURLPath.setText("");
			m_boxURL.add(m_textFieldURLPath);
		}
		return m_boxURL;
	}
	
	private Box getBoxWeb() {
		if (m_boxWeb == null) {
			m_boxWeb = Box.createHorizontalBox();
			m_labelWebPath = new JLabel();
			m_labelWebPath.setText(getText("m_labelWebPath"));
			m_boxWeb.add(m_labelWebPath);
			m_boxWeb.add(Box.createHorizontalStrut(30));
			m_boxWeb.add(Box.createGlue());
			m_textFieldWebPath = new JTextField(20);
			m_textFieldWebPath.setMaximumSize(m_textFieldWebPath
					.getPreferredSize());
			m_boxWeb.add(m_textFieldWebPath);
			m_textFieldWebPath.setEnabled(false);
			
		}
		return m_boxWeb;
	}
	
	private Box getBoxKey() {
		if (m_boxKey == null) {
			m_boxKey = Box.createHorizontalBox();
			m_labelKey = new JLabel();
			m_labelKey.setText(getText("m_labelKey"));
			m_boxKey.add(m_labelKey);
			m_boxKey.add(Box.createHorizontalStrut(56));
			m_boxKey.add(Box.createGlue());
			m_textFieldKey = new JTextField(20);
			m_textFieldKey.setMaximumSize(m_textFieldKey
					.getPreferredSize());
			m_textFieldKey.setText("");
			m_boxKey.add(m_textFieldKey);
		}
		return m_boxKey;
	}

	private Box getBoxPassword() {
		if (m_boxPassword == null) {
			m_boxPassword = Box.createHorizontalBox();
			m_labelPassword = new JLabel();
			m_labelPassword.setText(getText("m_labelPassword"));
			m_boxPassword.add(m_labelPassword);
			m_boxPassword.add(Box.createHorizontalStrut(18));
			m_boxPassword.add(Box.createGlue());
			m_textFieldPassword = new JPasswordField(20);
			m_textFieldPassword.setMaximumSize(m_textFieldPassword
					.getPreferredSize());
			m_textFieldPassword.setText("");
			m_boxPassword.add(m_textFieldPassword);
		}
		return m_boxPassword;
	}

	private Box getBoxConfirm() {
		if (m_boxConfirm == null) {
			m_boxConfirm = Box.createHorizontalBox();
			m_boxConfirm.add(Box.createGlue());
			m_buttonConfirm = new JButton();
			m_buttonConfirm.setText(getText("m_buttonConfirm"));
			m_buttonConfirm.addActionListener(new ActionListener() {

				public void actionPerformed(ActionEvent e) {
					try {
						EngineType type = ((ComboxData) m_comboBoxEngineType
								.getSelectedItem()).getEngineType();
						if (m_name.equals(getText("m_name4"))) {
							// 根据不同的引擎类型,打开不同的数据源
							// Open different datasources according to the engine types
							if (type.equals(EngineType.IMAGEPLUGINS)) {
								m_sampleRun.openDatasourceImagePlugins(
										m_textFieldPath.getText());
							} else if (type.equals(EngineType.UDB)) {
								m_sampleRun.openDatasourceUdbPlus(
										m_textFieldPath.getText());
							} else if (type.equals(EngineType.ORACLEPLUS)) {
								m_sampleRun.openDatasourceOracle(
										m_textFieldServer.getText(),
										m_textFieldDatabase.getText(),
										m_textFieldUserName.getText(),
										m_textFieldPassword.getText());
							} else if (type.equals(EngineType.SQLPLUS)) {
								m_sampleRun.openDatasourceSqlServer(
										m_textFieldServer.getText(),
										m_textFieldDatabase.getText(),
										m_textFieldUserName.getText(),
										m_textFieldPassword.getText());
							} else if (type.equals(EngineType.POSTGRESQL)) {
								m_sampleRun.openDatasourcePostgreSQL(
										m_textFieldServer.getText(),
										m_textFieldDatabase.getText(),
										m_textFieldUserName.getText(),
										m_textFieldPassword.getText());
							} else if (type.equals(EngineType.DB2)) {
								m_sampleRun.openDatasourceDB2(
										m_textFieldDatabase.getText(),
										m_textFieldUserName.getText(),
										m_textFieldPassword.getText());
							} else if (type.equals(EngineType.OGC)) {
								m_sampleRun.openDatasourceOGCPlus(
										m_textFieldURLPath.getText());
							} else if (type.equals(EngineType.GOOGLEMAPS)) {
								m_sampleRun.openDatasourceGoogleMaps(
								        m_textFieldWebPath.getText(),
								        m_textFieldKey.getText());
							} else if (type.equals(EngineType.SUPERMAPCLOUD)) {
								m_sampleRun.openDatasourceSuperMapCloud(
										m_textFieldWebPath.getText());
							} else if (type.equals(EngineType.ISERVERREST)) {
								m_sampleRun.openDatasourceISERVERREST(
										m_textFieldURLPath.getText());
							}
						} else {
							if (type.equals(EngineType.UDB)) {
								m_sampleRun.createDatasourceUdbPlus(
										m_textFieldPath.getText(),
										m_textFieldDatabase.getText());
							} else if (type.equals(EngineType.ORACLEPLUS)) {
								m_sampleRun.createDatasourceOracle(
										m_textFieldServer.getText(),
										m_textFieldDatabase.getText(),
										m_textFieldUserName.getText(),
										m_textFieldPassword.getText());
							} else if (type.equals(EngineType.SQLPLUS)) {
								m_sampleRun.createDatasourceSqlServer(
										m_textFieldServer.getText(),
										m_textFieldDatabase.getText(),
										m_textFieldUserName.getText(),
										m_textFieldPassword.getText());
							} else if (type.equals(EngineType.POSTGRESQL)) {
								m_sampleRun.createDatasourcePostgreSQL(
										m_textFieldServer.getText(),
										m_textFieldDatabase.getText(),
										m_textFieldUserName.getText(),
										m_textFieldPassword.getText());
							} else if (type.equals(EngineType.DB2)) {
								m_sampleRun.createDatasourceDB2(
										m_textFieldDatabase.getText(),
										m_textFieldUserName.getText(),
										m_textFieldPassword.getText());
							}
						}

					} catch (Exception ex) {
						System.out.println(ex.getMessage());
					}
				}
			});
			m_boxConfirm.add(m_buttonConfirm);
		}

		return m_boxConfirm;
	}

	// 清空TextField内容
	// Clear TextField contents
	private void clearTextField() {

		m_textFieldServer.setText("");
		m_textFieldPath.setText("");
		m_textFieldDatabase.setText("");
		m_textFieldUserName.setText("");
		m_textFieldPassword.setText("");
		m_textFieldURLPath.setText("");
		m_textFieldWebPath.setText("");
		m_textFieldKey.setText("");
	}
	
	// 根据语言设置text是中文还是英文
	// To change text to English or Chinede by CurrentCulture
	private String getText(String id)
	{
		String text = "";
		if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if(id == "m_name1")
			{
				text = "新建";
			} 
			if(id == "m_name2")
			{
				text = "数据源名称";
			} 
			if(id == "m_name3")
			{
				text = "数据库名称";
			} 
			if(id == "m_name4")
			{
				text = "打开";
			}
			if(id == "m_labelEngineType")
			{
				text = "引擎类型";
			} 
			if(id == "m_labelPath")
			{
				text = "路径";
			} 
			if(id == "m_buttonBrowse")
			{
				text = "浏览";
			} 
			if(id == "m_labelServer")
			{
				text = "服务名称";
			} 
			if(id == "m_labelUserName")
			{
				text = "用户名称";
			} 
			if(id == "m_labelURLPath")
			{
				text = "网址";
			} 
			if(id == "m_labelWebPath")
			{
				text = "服务地址";
			} 
			if(id == "m_labelKey")
			{
				text = "密钥";
			} 
			if(id == "m_labelPassword")
			{
				text = "数据库密码";
			} 
			if(id == "m_buttonConfirm")
			{
				text = "确定";
			} 
		}
		else
		{
			if(id == "m_name1")
			{
				text = "Create";
			} 
			if(id == "m_name2")
			{
				text = "Datasource Name";
			} 
			if(id == "m_name3")
			{
				text = "Database Name";
			} 
			if(id == "m_name4")
			{
				text = "Open";
			}
			if(id == "m_labelEngineType")
			{
				text = "Engine Type";
			} 
			if(id == "m_labelPath")
			{
				text = "Path";
			} 
			if(id == "m_buttonBrowse")
			{
				text = "Browse";
			} 
			if(id == "m_labelServer")
			{
				text = "Server Name";
			} 
			if(id == "m_labelUserName")
			{
				text = "User Name";
			} 
			if(id == "m_labelURLPath")
			{
				text = "URL";
			} 
			if(id == "m_labelWebPath")
			{
				text = "Web Addreess";
			} 
			if(id == "m_labelKey")
			{
				text = "Encrypted Key";
			} 
			if(id == "m_labelPassword")
			{
				text = "Database Password";
			} 
			if(id == "m_buttonConfirm")
			{
				text = "Yes";
			} 
		}
		return text;
	}
	
}

/**
 * FileFilter 的一个实现,它使用指定的扩展名集合进行过滤。
 * Filtrate with the specified extension name.
 */
class FileNameExtensionFilter extends FileFilter {
	private String str = "";

	private ArrayList<String> m_extensions = new ArrayList<String>();

	public FileNameExtensionFilter(String description, String... extensions) {
		this.setDescription(description);
		for (String extension : extensions) {
			this.addExtension(extension);
		}
	}

	public void addExtension(String extension) {
		if (!extension.startsWith(".")) {
			extension = "." + extension;
		}
		m_extensions.add(extension.toLowerCase());
	}

	public String[] getExtensions() {
		String[] result = new String[m_extensions.size()];
		return m_extensions.toArray(result);
	}

	public void setDescription(String aDescription) {
		str = aDescription;
	}

	public String getDescription() {
		return str;
	}

	@Override
	public boolean accept(File f) {
		if (f.isDirectory()) {
			return true;
		}
		String name = f.getName().toLowerCase();
		for (String extension : m_extensions) {
			if (name.endsWith(extension)) {
				return true;
			}
		}
		return false;
	}
}

