package com.supermap.samplecode.data;

import javax.swing.JScrollPane;
import javax.swing.JTextArea;

import com.supermap.data.Datasource;
import com.supermap.data.DatasourceConnectionInfo;
import com.supermap.data.EngineType;
import com.supermap.data.Workspace;

/**
 * <p>
 * Title:数据源管理
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明----------------------------
 * 此文件为SuperMap Objects Java 的示范代码 
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：示范如何打开和新建数据源
 * 2、示例数据：无
 * 3、关键类型/成员: 
 *      Datasources.open 方法
 *      Datasources.create 方法
 * 4、使用步骤：
 *  (1)点击“打开”面板，执行打开数据源的功能
 *  (2)点击“新建”面板，执行新建数据源的功能
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * </p>
 * 
 */

/**
 * <p>
 * Title Manage Datasource
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------Copyright Statement----------------------------
 * SuperMap Objects Java Sample Code 
 * Copyright: SuperMap Software Co., Ltd. All Rights Reserved.
 * ------------------------------------------------------------------------------
 *-----------------------Description--------------------------
 * 
 * 1.Sample Code Description: This sample demonstrates how to open and new a datasource
 * 2. Data: None
 * 3. Key classes and members 
 *      Datasources.open method
 *      Datasources.create method
 * 4. Steps:
 *   (1) Click the "Open" panel to implement the open datasource operation.
 *   (2) Click the "New" panel to implement the new datasource operation.
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * CopyRight: SuperMap Software Co., Ltd.
 * </p>
 * 
 */

public class SampleRun {
	private Workspace m_workspace;

	private JTextArea m_textArea;


	//执行所需要的数据
	//Data
	private String m_info1 = "";
	private String m_info2 = "";
	private String m_info3 = "";
	private String m_info4 = "";
	private String m_info5 = "";
	private String m_info6 = "";
	private String m_opensu = "";
	private String m_openfa = "";
	private String m_createsu = "";
	private String m_createfa = "";
	/**
	 * 构造 SampleRun对象
	 * Initialize the SampleRun object
	 */
	public SampleRun(Workspace workspace, JTextArea textArea,
			JScrollPane scrollPane) {
		this.m_workspace = workspace;
		this.m_textArea = textArea;
		InitializeCultureResources();
	}
	/**
	* 初始化多语言资源
	* Initialize CultureResources
	*/
	private void InitializeCultureResources()
	{
		if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			m_info1 = "数据源基本信息：\n";
			m_info2 = "实例名称:  ";
			m_info3 = "引擎类型:  ";
			m_info4 = "数据源中数据集信息：\n";
			m_info5 = "数据集名称: ";
			m_info6 = "数据源中没有数据集!";
			m_opensu = "数据源打开成功!";
			m_openfa = "数据源打开失败!";
			m_createsu = "数据源创建成 功!";
			m_createfa = "数据源创建失 败!";
		}
		else
		{
			m_info1 = "Datasource information:\n";
			m_info2 = "Instance name: ";
			m_info3 = "Engine Type: ";
			m_info4 = "Dataset information: \n";
			m_info5 = "Dataset name: ";
			m_info6 = "No dataset in the dtasource!";
			m_opensu = "Datasource Open Successfully!";
			m_openfa = "Datasource Open Failed!";
			m_createsu = "Datasource Create Successfully!";
			m_createfa = "Datasource Create Failed!";
		}
	}

	/**
	 * 向文本域中添加打开的数据源的信息
	 * Add datasource information to the text
	 */
	private void appendDatasourceInfo(Datasource datasource, String value) {
		try {
			m_textArea.setText("");
			m_textArea.append(value + "\n");
			m_textArea.append(m_info1);
			m_textArea.append(m_info2);
			m_textArea
					.append(datasource.getConnectionInfo().getServer() + "\n");
			m_textArea.append(m_info3);
			m_textArea.append(datasource.getConnectionInfo().getEngineType()
					.toString()
					+ "\n");

			m_textArea.append("********************\n");

			m_textArea.append(m_info4);
			if (datasource.getDatasets().getCount() > 0) {
				for (int i = 0; i < datasource.getDatasets().getCount(); i++) {
					m_textArea.append(m_info5
							+ datasource.getDatasets().get(i).getName()
							+ "      "
							+ datasource.getDatasets().get(i).getType() + "\n");
				}
			} else {
				m_textArea.append(m_info6);
			}
		} catch (Exception e) {
			System.out.println(e.getMessage());
		}
	}

	/**
	 * 向文本域中添加打开失败或创建失败的信息
	 * Add the failed information to the text area.
	 */
	private void appendFailedDatasourceInfo(String value) {
		m_textArea.setText("");
		m_textArea.append(value + "\n");
	}

	/**
	 * 打开影像数据源
	 * Open image datasource
	 */
	public void openDatasourceImagePlugins(String path) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.IMAGEPLUGINS);
			info.setServer(path);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"\n"+ex.getMessage());
		}

	}



	/**
	 * 打开udb数据源
	 * Open the udb datasource
	 */
	public void openDatasourceUdbPlus(String path) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.UDB);
			info.setServer(path);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"!\n"+ex.getMessage());
		}

	}

	/**
	 * 打开oracle数据源
	 * Open the oracle datasource. 
	 */
	public void openDatasourceOracle(String server, String database,
			String userName, String password) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.ORACLEPLUS);
			info.setServer(server);
			info.setDatabase(database);
			info.setUser(userName);
			info.setPassword(password);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"\n"+ex.getMessage());
		}
	}

	/**
	 * 打开SQL server数据源
	 * Open the SQL server datasource
	 */
	public void openDatasourceSqlServer(String server, String database,
			String userName, String password) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.SQLPLUS);
			info.setServer(server);
			info.setDatabase(database);
			info.setUser(userName);
			info.setPassword(password);
			info.setDriver("SQL SERVER");
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"!\n"+ex.getMessage());
		}

	}

	/**
	 * 打开PostgreSQL数据源
	 * Open the PostgreSQL datasource
	 */
	public void openDatasourcePostgreSQL(String server, String database,
			String userName, String password) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.POSTGRESQL);
			info.setServer(server);
			info.setDatabase(database);
			info.setUser(userName);
			info.setPassword(password);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"!\n"+ex.getMessage());
		}
	}
	
	/**
	 * 打开DB2数据源
	 * Open the DB2 datasource
	 */
	public void openDatasourceDB2(String database,
			String userName, String password) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.DB2);
			info.setDatabase(database);
			info.setUser(userName);
			info.setPassword(password);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"!\n"+ex.getMessage());
		}
	}
	
	/**
	 * 打开OGC数据源 
	 * Open the OGC datasource 
	 */
	public void openDatasourceOGCPlus(String path) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.OGC);
			info.setServer(path);
			// 这里只允许设置WMS和WFS两种类型,具体看发布的网络数据源类型
			// Only the WMS and WFS type database can be set.
			info.setDatabase("WMS");
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"!\n"+ex.getMessage());
		}
	}
	
	/**
	 * 打开GoogleMaps数据源 
	 * Open the GoogleMaps datasource
	 */
	public void openDatasourceGoogleMaps(String path, 
			String key) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.GOOGLEMAPS);
			info.setServer(path);
			info.setPassword(key);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"\n"+ex.getMessage());
		}
	}
	
	/**
	 *打开SuperMapCloud数据源 
	 * Open the SuperMapCloud datasource 
	 */
	public void openDatasourceSuperMapCloud(String path) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.SUPERMAPCLOUD);
			info.setServer(path);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"!\n"+ex.getMessage());
		}
	}
	
	/**
	 * 打开 ISERVERREST 数据源 
	 * Open the ISERVERREST datasource 
	 */
	public void openDatasourceISERVERREST(String path) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.ISERVERREST);
			info.setServer(path);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"!\n"+ex.getMessage());
		}
	}
		
	/**
	 * 打开MapWorld数据源 
	 * Open the MapWorld datasource
	 */
	 
	/*public void openDatasourceMapWorld(String path) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.MAPWORLD);
			info.setServer(path);
			Datasource ds = m_workspace.getDatasources().open(info);
			// 打开成功,输出数据源相关信息
			// Open successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_opensu);
			} else {
				appendFailedDatasourceInfo(m_openfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_openfa+"!\n"+ex.getMessage());
		}
	}*/	
	
	/**
	 * 创建udb数据源
	 * Create UDB datasource
	 */
	public void createDatasourceUdbPlus(String path, String database) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.UDB);
			info.setServer(path + "/" + database);
			Datasource ds = m_workspace.getDatasources().create(info);
			// 创建成功,输出数据源相关信息
			// Create successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_createsu);
			} else {
				appendFailedDatasourceInfo(m_createfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo(m_createfa+"!\n"+ex.getMessage());
		}
	}



	/**
	 * 创建Oracle数据源
	 * Create the Oracle datasource.
	 */
	public void createDatasourceOracle(String server, String database,
			String userName, String password) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.ORACLEPLUS);
			info.setServer(server);
			info.setDatabase(database);
			info.setUser(userName);
			info.setPassword(password);
			Datasource ds = m_workspace.getDatasources().create(info);
			// 创建成功,输出数据源相关信息
			// Create successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_createsu);
			} else {
				appendFailedDatasourceInfo(m_createfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo("Datasource Initialize Failed!\n"+ex.getMessage());
		}
	}

	/**
	 * 创建SQL Server数据源
	 * Create the SQL server datasource
	 */
	public void createDatasourceSqlServer(String server, String database,
			String userName, String password) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.SQLPLUS);
			info.setServer(server);
			info.setDatabase(database);
			info.setUser(userName);
			info.setPassword(password);
			info.setDriver("SQL SERVER");
			Datasource ds = m_workspace.getDatasources().create(info);
			// 创建成功,输出数据源相关信息
			// Create successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_createsu);
			} else {
				appendFailedDatasourceInfo(m_createfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();

		} catch (Exception ex) {
			appendFailedDatasourceInfo("Datasource Initialize Failed!\n"+ex.getMessage());
		}
	}
	
	/**
	 * 创建PostgreSQL数据源
	 */
	public void createDatasourcePostgreSQL(String server, String database,
			String userName, String password) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.POSTGRESQL);
			info.setServer(server);
			info.setDatabase(database);
			info.setUser(userName);
			info.setPassword(password);
			Datasource ds = m_workspace.getDatasources().create(info);
			// 创建成功,输出数据源相关信息
			// Create successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_createsu);
			} else {
				appendFailedDatasourceInfo(m_createfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo("Datasource Initialize Failed!\n"+ex.getMessage());
		}
	}
	
	/**
	 * 创建DB2数据源
	 * Create the DB2 datasource
	 */
	public void createDatasourceDB2(String database,
			String userName, String password) {
		try {
			DatasourceConnectionInfo info = new DatasourceConnectionInfo();
			info.setEngineType(EngineType.DB2);
			info.setDatabase(database);
			info.setUser(userName);
			info.setPassword(password);
			Datasource ds = m_workspace.getDatasources().create(info);
			// 创建成功,输出数据源相关信息
			// Create successfully, and output the information of the datasource.
			if (ds != null) {
				appendDatasourceInfo(ds, m_createsu);
			} else {
				appendFailedDatasourceInfo(m_createfa);
			}
			// 关闭所有打开的数据源
			// Close all the opened datasource.
			m_workspace.getDatasources().closeAll();
		} catch (Exception ex) {
			appendFailedDatasourceInfo("Datasource Initialize Failed!\n"+ex.getMessage());
		}
	}
}

